@@ -85,39 +85,39 @@ test_that("print.disscoefs", {
 
 test_that("print.param", {
   p <- param.dcm(inf.prob = 0.1, rec.rate = 0.1)
-  expect_output(p, "DCM Parameters")
+  expect_output(print(p), "DCM Parameters")
 
   p <- param.icm(inf.prob = 0.1, rec.rate = 0.1)
-  expect_output(p, "ICM Parameters")
+  expect_output(print(p), "ICM Parameters")
 
   p <- param.net(inf.prob = 0.1, rec.rate = 0.1)
-  expect_output(p, "Network Model Parameters")
-  expect_output(p, "act.rate = 1")
+  expect_output(print(p), "Network Model Parameters")
+  expect_output(print(p), "act.rate = 1")
 })
 
 test_that("print.init", {
   i <- init.dcm(s.num = 10, i.num = 10)
-  expect_output(i, "DCM Initial Conditions")
+  expect_output(print(i), "DCM Initial Conditions")
 
   i <- init.icm(s.num = 10, i.num = 10)
-  expect_output(i, "ICM Initial Conditions")
-  expect_output(i, "status.rand = FALSE")
+  expect_output(print(i), "ICM Initial Conditions")
+  expect_output(print(i), "status.rand = FALSE")
 
   i <- init.net(s.num = 10, i.num = 10)
-  expect_output(i, "Network Model Initial Conditions")
-  expect_output(i, "status.rand = FALSE")
+  expect_output(print(i), "Network Model Initial Conditions")
+  expect_output(print(i), "status.rand = FALSE")
 })
 
 test_that("print.control", {
   co <- control.dcm(type = "SI", nsteps = 10)
-  expect_output(co, "DCM Control Settings")
-  expect_output(co, "odemethod = rk4")
+  expect_output(print(co), "DCM Control Settings")
+  expect_output(print(co), "odemethod = rk4")
 
   co <- control.icm(type = "SI", nsteps = 10)
-  expect_output(co, "ICM Control Settings")
-  expect_output(co, "Built-In Modules: initialize.FUN")
+  expect_output(print(co), "ICM Control Settings")
+  expect_output(print(co), "Built-In Modules: initialize.FUN")
 
   co <- control.net(type = "SI", nsteps = 10)
-  expect_output(co, "Network Model Control Settings")
-  expect_output(co, "Built-In Modules: initialize.FUN")
+  expect_output(print(co), "Network Model Control Settings")
+  expect_output(print(co), "Built-In Modules: initialize.FUN")
 })
